# CTF-Architect

---

<p align="center">
    <a href="https://pypi.org/project/ctf-architect/" target="_blank">
        <img alt="PyPI - Version" src="https://img.shields.io/pypi/v/ctf-architect">
    </a>
    <a href="https://pypi.org/project/ctf-architect/" target="_blank">
        <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/ctf-architect">
    </a>
</p>

---

Github: <a href="https://github.com/Jus-Codin/CTF-Architect" target="_blank">https://github.com/Jus-Codin/CTF-Architect</a>

Documentation: <a href="https://jus-codin.github.io/CTF-Architect/" target="_blank">https://jus-codin.github.io/CTF-Architect/</a>

---

CTF Architect is a tool for managing challenges for CTFs.

Warning: This tool is still a work in progress, bugs are to be expected. If you find any, please open an [issue](https://github.com/Jus-Codin/CTF-Architect/issues)


## Installation
Refer to the [installation guide](./guides/installation.md) for instructions on how to install CTF-Architect.

## Usage
- [For Challenge Creators](./guides/packaging-challenges.md)
- [For CTF Organizers](./guides/repository-setup.md)